<?php $TRANSLATIONS = array(
"Unable to load list from App Store" => "ไม่สามารถโหลดรายการจาก App Store ได้",
"Authentication error" => "เกิดข้อผิดพลาดเกี่ยวกับสิทธิ์การเข้าใช้งาน",
"Group already exists" => "มีกลุ่มดังกล่าวอยู่ในระบบอยู่แล้ว",
"Unable to add group" => "ไม่สามารถเพิ่มกลุ่มได้",
"Could not enable app. " => "ไม่สามารถเปิดใช้งานแอปได้",
"Email saved" => "อีเมลถูกบันทึกแล้ว",
"Invalid email" => "อีเมลไม่ถูกต้อง",
"Unable to delete group" => "ไม่สามารถลบกลุ่มได้",
"Unable to delete user" => "ไม่สามารถลบผู้ใช้งานได้",
"Language changed" => "เปลี่ยนภาษาเรียบร้อยแล้ว",
"Invalid request" => "คำร้องขอไม่ถูกต้อง",
"Admins can't remove themself from the admin group" => "ผู้ดูแลระบบไม่สามารถลบตัวเองออกจากกลุ่มผู้ดูแลได้",
"Unable to add user to group %s" => "ไม่สามารถเพิ่มผู้ใช้งานเข้าไปที่กลุ่ม %s ได้",
"Unable to remove user from group %s" => "ไม่สามารถลบผู้ใช้งานออกจากกลุ่ม %s ได้",
"Couldn't update app." => "ไม่สามารถอัพเดทแอปฯ",
"Update to {appversion}" => "อัพเดทไปเป็นรุ่น {appversion}",
"Disable" => "ปิดใช้งาน",
"Enable" => "เปิดใช้งาน",
"Please wait...." => "กรุณารอสักครู่...",
"Updating...." => "กำลังอัพเดทข้อมูล...",
"Error while updating app" => "เกิดข้อผิดพลาดในระหว่างการอัพเดทแอปฯ",
"Error" => "ข้อผิดพลาด",
"Updated" => "อัพเดทแล้ว",
"Saving..." => "กำลังบันทึุกข้อมูล...",
"deleted" => "ลบแล้ว",
"undo" => "เลิกทำ",
"Groups" => "กลุ่ม",
"Group Admin" => "ผู้ดูแลกลุ่ม",
"Delete" => "ลบ",
"__language_name__" => "ภาษาไทย",
"Security Warning" => "คำเตือนเกี่ยวกับความปลอดภัย",
"Your data directory and your files are probably accessible from the internet. The .htaccess file that ownCloud provides is not working. We strongly suggest that you configure your webserver in a way that the data directory is no longer accessible or you move the data directory outside the webserver document root." => "ไดเร็กทอรี่ข้อมูลและไฟล์ของคุณสามารถเข้าถึงได้จากอินเทอร์เน็ต ไฟล์ .htaccess ที่ ownCloud มีให้ไม่สามารถทำงานได้อย่างเหมาะสม เราขอแนะนำให้คุณกำหนดค่าเว็บเซิร์ฟเวอร์ใหม่ในรูปแบบที่ไดเร็กทอรี่เก็บข้อมูลไม่สามารถเข้าถึงได้อีกต่อไป หรือคุณได้ย้ายไดเร็กทอรี่ที่ใช้เก็บข้อมูลไปอยู่ภายนอกตำแหน่ง root ของเว็บเซิร์ฟเวอร์แล้ว",
"More" => "มาก",
"Version" => "รุ่น",
"Developed by the <a href=\"http://ownCloud.org/contact\" target=\"_blank\">ownCloud community</a>, the <a href=\"https://github.com/owncloud\" target=\"_blank\">source code</a> is licensed under the <a href=\"http://www.gnu.org/licenses/agpl-3.0.html\" target=\"_blank\"><abbr title=\"Affero General Public License\">AGPL</abbr></a>." => "พัฒนาโดย the <a href=\"http://ownCloud.org/contact\" target=\"_blank\">ชุมชนผู้ใช้งาน ownCloud</a>, the <a href=\"https://github.com/owncloud\" target=\"_blank\">ซอร์สโค้ด</a>อยู่ภายใต้สัญญาอนุญาตของ <a href=\"http://www.gnu.org/licenses/agpl-3.0.html\" target=\"_blank\"><abbr title=\"Affero General Public License\">AGPL</abbr></a>.",
"Add your App" => "เพิ่มแอปของคุณ",
"More Apps" => "แอปฯอื่นเพิ่มเติม",
"Select an App" => "เลือก App",
"See application page at apps.owncloud.com" => "ดูหน้าแอพพลิเคชั่นที่ apps.owncloud.com",
"<span class=\"licence\"></span>-licensed by <span class=\"author\"></span>" => "<span class=\"licence\"></span>-ลิขสิทธิ์การใช้งานโดย <span class=\"author\"></span>",
"Update" => "อัพเดท",
"User Documentation" => "เอกสารคู่มือการใช้งานสำหรับผู้ใช้งาน",
"Administrator Documentation" => "เอกสารคู่มือการใช้งานสำหรับผู้ดูแลระบบ",
"Online Documentation" => "เอกสารคู่มือการใช้งานออนไลน์",
"Forum" => "กระดานสนทนา",
"Bugtracker" => "Bugtracker",
"Commercial Support" => "บริการลูกค้าแบบเสียค่าใช้จ่าย",
"You have used <strong>%s</strong> of the available <strong>%s</strong>" => "คุณได้ใช้งานไปแล้ว <strong>%s</strong> จากจำนวนที่สามารถใช้ได้ <strong>%s</strong>",
"Show First Run Wizard again" => "แสดงหน้าจอวิซาร์ดนำทางครั้งแรกอีกครั้ง",
"Password" => "รหัสผ่าน",
"Your password was changed" => "รหัสผ่านของคุณถูกเปลี่ยนแล้ว",
"Unable to change your password" => "ไม่สามารถเปลี่ยนรหัสผ่านของคุณได้",
"Current password" => "รหัสผ่านปัจจุบัน",
"New password" => "รหัสผ่านใหม่",
"Change password" => "เปลี่ยนรหัสผ่าน",
"Display Name" => "ชื่อที่ต้องการแสดง",
"Email" => "อีเมล์",
"Your email address" => "ที่อยู่อีเมล์ของคุณ",
"Fill in an email address to enable password recovery" => "กรอกที่อยู่อีเมล์ของคุณเพื่อเปิดให้มีการกู้คืนรหัสผ่านได้",
"Language" => "ภาษา",
"Help translate" => "ช่วยกันแปล",
"WebDAV" => "WebDAV",
"Use this address to connect to your ownCloud in your file manager" => "ใช้ที่อยู่นี้เพื่อเชื่อมต่อกับ ownCloud ในโปรแกรมจัดการไฟล์ของคุณ",
"Login Name" => "ชื่อที่ใช้สำหรับเข้าสู่ระบบ",
"Create" => "สร้าง",
"Default Storage" => "พื้นที่จำกัดข้อมูลเริ่มต้น",
"Unlimited" => "ไม่จำกัดจำนวน",
"Other" => "อื่นๆ",
"Storage" => "พื้นที่จัดเก็บข้อมูล",
"change display name" => "เปลี่ยนชื่อที่ต้องการให้แสดง",
"set new password" => "ตั้งค่ารหัสผ่านใหม่",
"Default" => "ค่าเริ่มต้น"
);
